@@ -1,9 +1,10 @@
 package EntityModel::Array;
-$EntityModel::Array::VERSION = '0.015';
+$EntityModel::Array::VERSION = '0.016';
 use strict;
 use warnings;
-use 5.010;
+
 use parent qw(Mixin::Event::Dispatch);
+
 use EntityModel::Log ':all';
 
 =head1 NAME
@@ -12,7 +13,7 @@ EntityModel::Array - wrapper object for dealing with arrayrefs
 
 =head1 VERSION
 
-version 0.015
+Version 0.016
 
 =head1 DESCRIPTION
 
@@ -352,4 +353,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2008-2011. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2008-2014. Licensed under the same terms as Perl itself.
