@@ -1,9 +1,7 @@
 package EntityModel::Class::Accessor;
-$EntityModel::Class::Accessor::VERSION = '0.015';
+$EntityModel::Class::Accessor::VERSION = '0.016';
 use strict;
-use warnings FATAL => 'all', NONFATAL => 'redefine';
-use 5.010;
-use feature ();
+use warnings;
 
 =head1 NAME
 
@@ -11,7 +9,7 @@ EntityModel::Class::Accessor - generic class accessor
 
 =head1 VERSION
 
-version 0.015
+Version 0.016
 
 =head1 DESCRIPTION
 
@@ -91,4 +89,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2008-2011. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2008-2014. Licensed under the same terms as Perl itself.
